-- Tag pi diffusi
/* 
	non considero solo il numero in generale, ma il numero di pagine sulle quali il tag  rilevato, rispetto al numero di pagine analizzate.
	questo valore inoltre  moltiplicato per il numero di siti sui quali il tag  presente (essere presente al 100% su un sito grosso  comunque meno importante
	che non essere presente al 70% nel resto degli altri siti)
*/
select tagId, tagName, count(distinct Sito) as siteCount,  sum(#pages) as pagesAnalyzed, sum(pagesContainingTag) as pagesWithTag, (sum(pagesContainingTag)/sum(#pages)) as presenceRatio, ((sum(pagesContainingTag)/sum(#pages))*(count(distinct Sito)/50.0)) as superPresenceRatio  from RawData group by tagId, tagName order by superPresenceRatio desc

-- Siti con pi tag
/*
	In questo caso utilizzo il numero di pagine analizzate (motiplicato per il numero di tag) come il valore di riferimento su cui calcolare la presenza di un tag.
	Se ho 10 tag ed ho fatto una scansione su 100 pagine, il sito sar "saturo" se ogni pagina ha tutti e 10 i tag. Ed un sito saturo in questo caso  un sito con "punteggio" 1000 (chiamo questo valore Y)
	A questo punto, calcolo il numero di pagine sui quali  stato rilevato ogni tag (chiamo questo valore X) ed il rapporto X/Y rappresenta il livello di "saturazione".

	Questo valore per non  sufficiente, perch non mi permette il confronto con altri siti. Un sito saturo al 100% con 2 tag  diverso da un sito saturo al 100% con 200 tag.
	Ecco allora che, banalmente, ottengo un livello di saturazione "comparabile" con gli altri siti, moltiplicando il rapporto X/Y per il numero di tag del sito.
	Un sito saturo al 100% con 2 tag avr quindi lo stesso valore di un sito saturo all'1% con 200 tag.

	Di fatto  il numero medio di tag per pagina (o no?)

	Nel primo caso sono certo che, qualunque sia la mia navigazione, otterr 2 tag.
	Nel secondo caso, avr una probabilit simile di essere tracciato dai 2 tag.

	Questa  una semplificazione poich, quantomeno, la homepage  una pagina che incide pi delle altre. Tuttavia in questo momento, considero tutte le pagine allo stesso modo
*/
select Sito, category, country, #tags, sum(#pages) as maxValue, sum(pagesContainingTag) as presenceValue, sum(pagesContainingTag)/sum(#pages) as presenceRatio, #tags*(sum(pagesContainingTag)/sum(#pages)) as P from RawData group by Sito, category, country, #tags order by P desc
-- ordinati per numero di tag
select Sito, category, country, #tags, sum(#pages) as maxValue, sum(pagesContainingTag) as presenceValue, sum(pagesContainingTag)/sum(#pages) as presenceRatio, #tags*(sum(pagesContainingTag)/sum(#pages)) as P from RawData where country='italiano' group by Sito, category, country, #tags order by #tags desc

-- Media di tag per categoria
/*
	Per quanto la classificazione non sia precisa (virgilio  anche un portale di ricerca... wikipedia non sapevo dove classificarla ed  finita in "varie" la categoria news e la categoria
	adulti non  difficile da individuare. peraltro sono le due categorie con pi siti (6) e sono agli "antipodi" (la seconda e la penultima).
	Per rendere i dati ancora pi puliti, ho considerato solo le scansioni da pi di 80 pagine
*/
select 
	category, 
	AVG(#tags) as avgTags, 
	count(distinct Sito) as countSites, 
	count(isnull(tagName,'none')) as countTags, 
	AVG(isnull(#pages,0)) as avgAnalyzedPages, 
	(count(isnull(tagName,'none'))/count(distinct Sito)) as avgTagsPerSite 
from RawData where #pages>0 group by category order by avgTagsPerSite desc


select distinct category, Sito, #tags, #pages from RawData order by category

update RawData set category='brand' where Sito='Aruba.it'

-- Media di tag per nazione
/*
	simile al precedente, ma aggregato per nazione... solo che di fatto si tratta di un confronto tra italia e USA (impreciso perch non ho approfondito tutti quelli che stanno in ALTRO)
*/
select country, AVG(#tags) as avgTags, count(distinct Sito) as countSites, count(tagName) as countTags, AVG(#pages) as avgAnalyzedPages, (count(tagName)/count(distinct Sito)) as avgTagsPerSite from RawData where #pages>80 group by country order by avgTagsPerSite desc


-- tag pi diffusi per categoria
/*
	Questo  un po' pi complesso da analizzare. Estrapola i primi N tag da ogni categoria per il valore di SuperPresenceRation
	Non so quanto sia utile o facile da comunicare... per ora lasciamola cos

	Una cosa che emerge  che analizzando i primi 3 tag per ogni categoria, Google Analytics compare in 8 categoria su 14, con una posizione media di 1.375
	Insomma, la query qui sotto  composta da tre query annidate.
		La pi interna serve a creare i segmenti
		La seconda serve a selezionare solo i primi N segmenti
		L'ultima raggruppa per tag e ne calcola la posizione media


	Selezionando tutti i segmenti, indipendentemente dal rank, si ottiene il risultato finale che ci dice, per ogni tag, qual  la sua posizione
	media nei vari segmenti
	E le prime 5 posizioni sono tutte di Google
*/

select tagname, count(*) as categoryCount, avg(1.0*rank) as avgRank, avg(superPresenceRatio) as avgSPR
from
(
	select 
		category, tagName, superPresenceRatio, rank
	from
	(
		select 
			category,
			tagId, 
			isnull(tagName, 'none') as tagName, 
			count(distinct Sito) as siteCount,  
			sum(#pages) as pagesAnalyzed, 
			sum(pagesContainingTag) as pagesWithTag, 
			(sum(pagesContainingTag)/sum(#pages)) as presenceRatio, 
			((sum(pagesContainingTag)/sum(#pages))*(count(distinct Sito)/50.0)) as superPresenceRatio,  
			rank() over (partition by category order by ((sum(pagesContainingTag)/sum(#pages))*(count(distinct Sito)/50.0)) desc) as rank
		from RawData 
		group by category, tagId, isnull(tagName, 'none') 
		--order by superPresenceRatio desc
	) Data
	--where Data.rank<4
	--order by tagName, superPresenceRatio
) RankData
group by RankData.tagName
order by categoryCount desc, avgRank, avgSPR desc